#
# spec file for package benchmark
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname  lib%{name}
%define sover   0
Name:           benchmark
Version:        1.4.1
Release:        4.1
Summary:        A microbenchmark support library
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://github.com/google/benchmark
Source:         https://github.com/google/benchmark/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  git-core
BuildRequires:  gmock
BuildRequires:  gtest
BuildRequires:  pkgconfig

%description
A library to support the benchmarking of functions, similar to unit-tests.

%package -n %{soname}%{sover}
Summary:        Shared library for google benchmark
Group:          System/Libraries

%description -n %{soname}%{sover}
A library to support the benchmarking of functions, similar to unit-tests.

%package devel
Summary:        Development files for google benchmark
Group:          Development/Languages/C and C++
Requires:       %{soname}%{sover} = %{version}

%description devel
Development files for google benchmark library

%prep
%setup -q

%build
sed -e 's|lib_install_dir "lib/"|lib_install_dir "%{_libdir}/"|g' \
    -e 's|config_install_dir "lib/cmake|config_install_dir "%{_libdir}/cmake|g' \
    -e 's|pkgconfig_install_dir "lib/pkgconfig"|pkgconfig_install_dir "%{_libdir}/pkgconfig"|g' \
    -i src/CMakeLists.txt
sed -e 's|libdir=${prefix}/lib|libdir=${prefix}/%{_lib}|' \
    -i cmake/benchmark.pc.in

%cmake \
  -DBENCHMARK_ENABLE_LTO=on \
  -DBENCHMARK_ENABLE_TESTING=true
%make_jobs

%install
%cmake_install
# dont ship debug stuff
rm -rf %{buildroot}%{_libexecdir}/debug

%check
# path needs to be exported otherwise unit tests will fail
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:%{_builddir}/%{name}-%{version}/build/src/
%ctest

%post -n %{soname}%{sover} -p /sbin/ldconfig
%postun -n %{soname}%{sover} -p /sbin/ldconfig

%files -n %{soname}%{sover}
%license LICENSE
%doc README.md AUTHORS
%{_libdir}/%{soname}.so.%{sover}*
%{_libdir}/%{soname}_main.so.%{sover}*

%files devel
%license LICENSE
%doc README.md AUTHORS
%dir %{_libdir}/cmake/%{name}
%{_libdir}/cmake/%{name}/*.cmake
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/%{soname}.so
%{_libdir}/%{soname}_main.so
%{_includedir}/%{name}

%changelog
* Sat Feb 23 2019 Luigi Baldoni <aloisio@gmx.com>
- Use arch-specific libdir in pkgconfig file
* Mon Feb 18 2019 Luigi Baldoni <aloisio@gmx.com>
- Use arch-specific directories for support files
* Mon Jun 25 2018 mpluskal@suse.com
- Enable lto
- Update dependencies
* Mon May 28 2018 avindra@opensuse.org
- Update to version 1.4.1
  * Realign expectation that State::iterations() returns 0 before
    the main benchmark loop begins.
  * CMake error message fixes
  * Enscripten check fix
  * Bazel pthread linking
  * Negative regexes
  * gmock fix
* Wed Apr  4 2018 avindra@opensuse.org
- Update to version 1.4.0
  * Removal of deprecated headers
  * Improved CPU cache info reporting
  * Support State::KeepRunningBatch()
  * Support int64_t for AddRange()
  * New platform support: NetBSD, s390x, Solaris
  * Bazel build support
  * Support googletest unit tests
  * Add assembler tests
  * Various warnings fixed
- Drop benchmark-s390.patch
  * fixed upstream (commit ff2c255af5bb2fc2e5cd3b3685f0c6283117ce73)
* Tue Mar 27 2018 stefan.bruens@rwth-aachen.de
- Remove ExclusiveArch, it works on non-x86 as well
* Fri Mar 16 2018 avindra@opensuse.org
- Update to version 1.3.0:
  * Ranged for loop optimization!
  * Make installation optional
  * Better stats including user-provided ones
  * JSON reporter format fixes
  * Documentation improvements
- Includes changes from 1.2.0:
  * User-defined counters
  * Single header library
  * Ability to clear benchmarks so the runtime registration is more flexible
  * Sample-based standard deviation
  * 32-bit build enabled
  * Bug fixes
- Cleanup with spec-cleaner
- Use %%ctest macro for testing
* Fri Jan 27 2017 mpluskal@suse.com
- Update to version 1.1.0:
  * ArgNames support
  * Fixes for OSX and Cygwin and MSVC builds
  * PauseTiming and ResumeTiming are per thread (#286)
  * Better Range and Arg specifications
  * Complexity reporting
* Fri Jan 27 2017 bg@suse.com
- add support for s390x:
  * benchmark-s390.patch
* Sat Nov 12 2016 ro@suse.de
- add ExclusiveArch, package is not ported to anything but
  x86 and x86_64
* Mon Jul  4 2016 mpluskal@suse.com
- Disable lto as it does not seem to go well with -fPIE
* Sat May 14 2016 mpluskal@suse.com
- Initial package for version 1.0.0
